{% extends "base.html" %}
{% block title %}404 - Halaman Tidak Ditemukan{% endblock %}
{% block content %}
<div class="card" style="text-align:center; padding: 3rem;">
    <h1>404</h1>
    <p>Halaman yang kamu cari tidak ditemukan.</p>
    <a href="/home">← Kembali ke Home</a>
</div>
{% endblock %}