"""add_oauth_columns_to_users

Revision ID: 2caf45d8d213
Revises: 43c661f2b25a
Create Date: 2026-04-22 16:04:41.083021

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '2caf45d8d213'
down_revision: Union[str, Sequence[str], None] = '43c661f2b25a'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('users', sa.Column('oauth_provider', sa.String(), nullable=True))
    op.add_column('users', sa.Column('oauth_id', sa.String(), nullable=True))
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('users', 'oauth_id')
    op.drop_column('users', 'oauth_provider')
    # ### end Alembic commands ###
