{% extends "base.html" %}
{% block title %}Maintenance{% endblock %}
{% block page_title %}Fitur Tidak Tersedia{% endblock %}

{% block content %}
<div style="display:flex;flex-direction:column;align-items:center;justify-content:center;
            min-height:60vh;text-align:center;gap:16px;padding:40px 20px">

  <div style="font-size:3.5rem;line-height:1">🔧</div>

  <h2 style="font-family:'Playfair Display',serif;font-size:1.4rem;
             font-weight:800;color:var(--text);margin-top:8px">
    {{ fitur }} Sedang Maintenance
  </h2>

  <p style="color:var(--muted);max-width:420px;line-height:1.75;font-size:.9rem">
    Fitur ini sedang dinonaktifkan sementara oleh administrator.<br>
    Silakan coba beberapa saat lagi atau hubungi admin untuk informasi lebih lanjut.
  </p>

  <div style="display:flex;gap:10px;margin-top:8px;flex-wrap:wrap;justify-content:center">
    <a href="/home" class="btn btn-primary">
      <svg width="14" height="14" fill="none" stroke="currentColor" stroke-width="2" viewBox="0 0 24 24">
        <path d="M3 9.5L12 3l9 6.5V20a1 1 0 01-1 1H4a1 1 0 01-1-1V9.5z"/>
        <path d="M9 21V12h6v9"/>
      </svg>
      Kembali ke Beranda
    </a>
  </div>

  <div class="alert alert-warning" style="max-width:420px;margin-top:16px">
    <svg width="15" height="15" fill="none" stroke="currentColor" stroke-width="2" viewBox="0 0 24 24">
      <path d="M10.29 3.86L1.82 18a2 2 0 001.71 3h16.94a2 2 0 001.71-3L13.71 3.86a2 2 0 00-3.42 0z"/>
      <line x1="12" y1="9" x2="12" y2="13"/><line x1="12" y1="17" x2="12.01" y2="17"/>
    </svg>
    <span>Jika ini dirasa tidak seharusnya terjadi, hubungi administrator sistem.</span>
  </div>

</div>
{% endblock %}